function [F]=compressor(Fi,hp)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% compressor - physical data out of compressor
%
% Inputs:    Fi - inlet flow compressor      [struct]
%            hp - force / power compressor   [hp]
%
% Outputs:   F  - outlet flow compressor     [struct]
%
%
% Written by   : Marius S. Govatsmark       19.sept.1998
% Last modified: Marius S. Govatsmark       22.aug.1999
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%define struct
  F=stream;

%Molflows
  F.F=Fi.F;
  Ftot=sum(F.F);
  x=Fi.F/Ftot;

%Molweight
  M=molweight(x);
  
%Density
  D=density(Fi.T,Fi.P,x,'VAP'); % VAP determines the calculation of a vapor/gas phase while LIQ is used for liquid phase calculations.

%Gamma
  G=gamma1(Fi.T,x);
  
%Pressure
  K=60*G*hp*D/(3.03e-005*144*Fi.P*Ftot*M);
  I=1/G;
  F.P=Fi.P*(1+K)^I;  
  
%Temperature
  F.T=(Fi.T+459.67)*(F.P/Fi.P)^G-459.67;

%Enthalpy out
  F.E=enthalpy(F);
