% Constraints

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Equality constraints

% Process model + quencher outlet temperature.
ceq = [dXdt;DF;(QFlow.T - 1150)];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Inequality constraints

% Reactor inlet temperature
c(1) = -Tfurnace + b(1);

% Product purity
c(2) = -xDben(3) + b(2);
c(3) =  xDben(3) - b(3);

% By-pass FEHE (zeta denotes the amount of recycle passing through the FEHE)
c(4) = -kbypass + b(4);

% Methane in recycle gas stream
c(5) = -(SepVapFlow.F(1)/sum(SepVapFlow.F)) + b(5);

% Production rate - benzene
c(6) = -Dben + b(6);

% Pure toluene feed rate
c(7) = Ftol - b(7);

% Reactor inlet pressure
c(8) = FurnaceFlow.P - b(8);

% Flash inlet temperature
c(9)  = -CoolerFlow.T + b(9);
c(10) =  CoolerFlow.T - b(10);

% Reactor inlet hydrogen-aromatics ratio  
c(11) = -FurnaceFlow.F(1)/sum(FurnaceFlow.F(3:5)) + b(11);

% Reactor outlet temperature
c(12) = Tcstr(19) - b(12);

% Bound on the volatile impurity (hydrogen plus methane) levels at
% stabilizer bottom
c(13) = (xBstab(1) + xBstab(2)) - b(13);

% Bounds on distillation columns
c(14) = V(1) - b(14);
c(15) = V(2) - b(15);
c(16) = V(3) - b(16);

c(17) = L(1) - b(17);
c(18) = L(2) - b(18);
c(19) = L(3) - b(19);

% Benzene mole fraction in stabilizer distillate (upper bound)
c(20) =  xDstab(3) - b(20);

% Toluene mole fraction in benzene column bottom (lower bound)
c(21) = -xBben(4) + b(21);

% Toluene mole fraction in toluene column distillate (lower bound)
c(22) = -xDtol(4) + b(22);

% Diphenyl mole fraction in toluene column bottom (lower bound)
c(23) = -xBtol(5) + b(23);

% Flash inlet valve opening
c(24) = -kfsep + b(24);

ceq = [ceq; c(2); c(4); c(7); c(9); c(11); c(13); c(20:23)'; c(24)];


