function [H2,C2,Q] = cooler(H1,C1,H2,C2)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% cooler - physical data out of cooler 
%
% Inputs:    F1  - inlet flow cooler                [struct]
%            F2  - outlet flow cooler               [struct]
%            Tw1 - inlet temperature cooling water  [F]
%            Tw2 - outlet temperature cooling water [F]
%
% Outputs:   F2  - outlet flow cooler               [struct]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% data - dyn73.res
   PDh = 0;               % pressure loss [psia]
   PDc = 0;
   Ar  = 1500;            % heat exchanger coefficient 

% mass balance
   H2.F = H1.F;
   C2.F = C1.F;
   
% pressure
   H2.P = H1.P  - PDh;
   C2.P = C1.P  - PDc;
   
% logarithmic temperature difference mean
   DT1 = H1.T - C2.T;
   DT2 = H2.T - C1.T;
   LM  = lmtd(DT1,DT2);
   
% duty from heat exchange
   Q = Ar*LM/10000;
   
% energy balance 
   H2.E = H1.E - Q;
   C2.E = C1.E + Q;
   

