function E = enthalpy(Flow)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% enthalpy - calculate enthalphy 
%
% Inputs:    Flow - flow         [struct]
%
% Outputs:   E    - enthalpy    [MTBU/H] 
%
%Written by: Marius Store Govatsmark (Wolff fortran)
%Date:       18. aug. 1998
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Temperature, pressure and flowstream from struct
  T=Flow.T;
  P=Flow.P;
  F=Flow.F;

%Boiling point from Antonines likning
      B = 5019.4/(15.901-log(51.7*P)) - 365.42;   
      C = 5573.8/(16.014-log(51.7*P)) - 363.06;
      D = 8284/(16.683-log(51.7*P))   - 332.92;

%Decide phase to each component      
      if (T>B) 
         S=1;
       else
         S=-1;
      end
      if (T>C) 
         U=1;
      else
         U=-1;
      end
      if (T>D) 
         V=1;
      else
         V=-1;
       end

%More vapour enthalpy       
      if (T<552.2) 
         I=1;
      else
         I=-1;
      end
      if (T<605.5) 
         J=1;
      else
         J=-1;
      end

%Liquid enthalpy        
     E=F(1)*(7.8275E-11*T^4-1.9517E-7*T^3+2.4685E-4*T^2+6.864*T-529.9)...
      +F(2)*(-1.158E-10*T^4+3.693E-7*T^3+2.956E-3*T^2+8.61*T-680.66)...
      +F(3)*(S-1)*(20.924*(77-T)+0.056*(5929-T^2))/2 ...
      +F(4)*(U-1)*(27.718*(77-T)+0.058*(5929-T^2))/2 ...
      +F(5)*(V-1)*(56.039*(77-T)+0.0267*(5929-T^2))/2;

%Vapour benzene
     E=E+F(3)*(S+1)*(30.323*(T-B)...
        +1.115E-2*(T^2-B^2)...
	-2.9837E-6*(T^3-B^3)...
        +7.3E-10*(T^4-B^4)...
	+20.924*(B-77)...
	+0.056*(B^2-5929)...
        +(I+1)*(+960.72*(abs(2761.1-5*T))^0.33333...
        -38.433*(abs(2761.1-5*T))^0.66667...
	+2.7826*(2761.1-5*T)...
        +1.3319*(abs(2761.1-5*T))^1.33333...
	-0.17307*(abs(2761.1-5*T))^1.66667...
        +5.8338E-3*(2761.1-5*T)^2)/2)/2;
 
%Vapour toluene    
      E=E+F(4)*(U+1)*(35.715*(T-C)...
         +1.5065E-2*(T^2-C^2)...
         -3.298E-6*(T^3-C^3)...
	 +5.0275E-10*(T^4-C^4)...
	 +27.718*(C-77)...
         +0.058*(C^2-5929)...
	 +(J+1)*(+1598.37*(abs(3027.8-5*T))^0.33333...
         -275.52*(abs(3027.8-5*T))^0.66667...
	 +66.621*(3027.8-5*T)...
         -7.9562*(abs(3027.8-5*T))^1.33333...
	 +0.47316*(abs(3027.8-5*T))^1.66667...
         -1.0649E-2*(3027.8-5*T)^2)/2)/2;

%Vapour diphenyl     
      E=E+F(5)*(V+1)*(31323.6-27.72*T...
	 +2.5935E-2*(T^2-D^2)...
         -1.239E-5*(T^3-D^3)...
	 +2.8575E-9*(T^4-D^4)...
	 +56.039*(D-77)...
         +0.0267*(D^2-5929)...
	 +68.621*(T-D))/2;

      E=E/1000000;
