function [H2,H3,C2,neta] = fehe(H,H2,C1,C2,kbypass,H3,cvbypass)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% fehe - physical  data out of preheater (fehe)
%
% Inputs:    H  - outlet flow quencher         [struct]
%            H2 - outlet flow fehe hot side    [struct] 
%            H3 - cooler inlet flow            [struct] 
%            C1 - outlet flow mixer            [struct] 
%            C2 - outlet flow fehe cold side   [struct] 
%            zeta - bypass ratio (Fbypass/Ftotal)  [-] 
%
% Outputs:   H2 - outlet flow fehe hot side    [struct] 
%            H3 - outlet flow bypass           [struct] 
%            C2 - outlet flow fehe cold side   [struct] 
%
%
%Written by   : Marius S. Govatsmark       18.aug.1998 
%Last modified: Marius S. Govatsmark       22.aug.1999
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Parameters
parameter

% Data - design - dyn73.res
   PDh = 10;    % pressure loss hot side  [psia]
   PDc = 20;    % pressure loss cold side [psia]
   Ar  = 5960;  % heat transfer coefficient

% mass balance
   C2.F = C1.F;
   
% pressure - fehe
   H2.P = H.P  - PDh;
   C2.P = C1.P - PDc;
   
% splitter
   H1    = H;
   Hb    = H;
   Hb.P  = H.P; % No pressure drop through the splitter
   Hbtot = kbypass*cvbypass*(Hb.P - H2.P)^0.5; % Here, the pressure after the by-pass valve equals H2.P!
   Hb.F  = Hbtot*(H.F./sum(H.F));
   Hb.E  = enthalpy(Hb);
   H1.F  = H.F - Hb.F;
   H1.E  = H.E - Hb.E;
   H2.F  = H1.F;
   neta  = sum(Hb.F)/sum(H.F);
  
% logarithmic temperature difference mean
   DT1 = H1.T - C2.T;
   DT2 = H2.T - C1.T;
   LM  = lmtd(DT1,DT2);
   
% duty from heat exchange
   Q = Ar*LM/10000;
   
% energy balance 
   H2.E = H1.E - Q;
   C2.E = C1.E + Q;

% mixer  
   H3.P = H2.P;
   H3.F = H.F;
   H3.E = H2.E + Hb.E;
   
