%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%% Connection %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
diff = x(1:ndiff);
diff = diff(:);

alg  = x(ndiff+1:ndiff_alg);
alg  = alg(:);

dXdt = zeros(size(diff));
DF   = zeros(size(alg));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PROCESS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Pure toluene 
FeedToluen      = stream;
FeedToluen.F    = [0;0;0;Ftol;0];
FeedToluen.P    = 50;                    %[psia] 
FeedToluen.T    = Ttol;
FeedToluen.E    = enthalpy(FeedToluen);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Make-up H2 
FeedGas         = stream;
FeedGas.F       = [Fgas*xhyd;Fgas*(1 - xhyd);0;0;0];
FeedGas.P       = 555;                   %[psia] 
FeedGas.T       = Tgas;
FeedGas.E       = enthalpy(FeedGas);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% RecGasFlow
RecGasFlow      = stream;
RecGasFlow.T    = alg(63);
RecGasFlow.P    = alg(64);
RecGasFlow.F    = alg(58:62);
RecGasFlow.E    = enthalpy(RecGasFlow);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% RecToluenFlow
RecToluen       = stream;
RecToluen.F     = [0;0;alg(65:67)];
RecToluen.T     = Trectol;
RecToluen.P     = 17.000;                %[psia]
RecToluen.E     = enthalpy(RecToluen);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Hot flow after quencher
PfrFlow         = stream;
PfrFlow.T       = alg(68);
PfrFlow.F       = alg(43:47);
DP              = 25 + 20 + 10 + 0;      % pressure drop from RecGas to reactor outlet: FEHE + furnace + reactor
PfrFlow.P       = RecGasFlow.P - DP;
PfrFlow.E       = enthalpy(PfrFlow);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MIXER
MixerFlow   = mixer(FeedToluen,FeedGas,RecToluen,RecGasFlow);
MixerFlow.T = alg(1);
DF(1)       = MixerFlow.E - enthalpy(MixerFlow);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FEHE
Feheh2Flow      = stream;
Feheh2Flow.T    = alg(2);
Feheh3Flow      = stream;
Feheh3Flow.T    = alg(3);
Fehec2Flow      = stream;
Fehec2Flow.T    = alg(4);

[Feheh2Flow,Feheh3Flow,Fehec2Flow,neta] = fehe(PfrFlow,Feheh2Flow,MixerFlow,Fehec2Flow,kbypass,Feheh3Flow,cvbypass);

DF(2) = Feheh2Flow.E - enthalpy(Feheh2Flow);
DF(3) = Feheh3Flow.E - enthalpy(Feheh3Flow);
DF(4) = Fehec2Flow.E - enthalpy(Fehec2Flow);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%FURNACE
Tfurnace = alg(70);
[FurnaceFlow,Qfurnace] = furnace(Fehec2Flow,Tfurnace,Wfuel,fuelval);

DF(70)   = FurnaceFlow.E - enthalpy(FurnaceFlow);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% REACTOR - plug-flow reactor modelled as a series of 19 CSTRs
Ct_cstr = diff(1:19);
Tcstr   = alg(5:23);  % temperature profile through the reactor, including the reactor outlet temperature!
xcstr   = alg(24:42); % conversion profile through the reactor, including the reactor outlet conversion!
Fpfr    = stream;
Fpfr.P  = PfrFlow.P;  % only pressure is passed to the function reactor.m! Note that there's no pressure drop through the quencher!

[Fpfr,dCdt,dF,F,E,F4,E0] = reactor(FurnaceFlow,Fpfr,Ct_cstr,Tcstr,xcstr);

DF(5:42) = dF;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COOLER
CoolerFlow      = stream;
CoolerFlow.T    = alg(69);
WaterFlowOut    = stream;
WaterFlowOut.T  = alg(48);
WaterFlowIn     = stream;
WaterFlowIn.F   = Wcooler;
WaterFlowIn.T   = Tcw1;
WaterFlowIn.P   = Pw;
WaterFlowIn.E   = WaterFlowIn.F*0.018*(WaterFlowIn.T - To);

[CoolerFlow,WaterFlowOut,Qcooler]  = cooler(Feheh3Flow,WaterFlowIn,CoolerFlow,WaterFlowOut);

DF(48) = WaterFlowOut.E - WaterFlowOut.F*0.018*(WaterFlowOut.T - To);
DF(69) = CoolerFlow.E   - enthalpy(CoolerFlow);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FLASH
[dXsepdt,df,SepLiqFlow,SepVapFlow,Pflash,Pflashliq] = flash(alg(49:56),diff(20:25),CoolerFlow,kvsep,klsep,kfsep,Pdownliq,cvfsep);
DF(49:56) = df;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% QUENCHER
[QFlow,nu]   = quencher(SepLiqFlow,Fpfr,kquencher,cvquencher);
QFlow.T      = alg(68);
DF(68)       = QFlow.E - enthalpy(QFlow);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Integration: Quencher - FEHE
DF(43:47) = QFlow.F - PfrFlow.F;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURGE
[PurgeRecFlow,PurgeOutFlow] = purge(SepVapFlow,kpurge,Pdown,cvpurge);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMPRESSOR
[CompFlow] = compressor(PurgeRecFlow,hpcompressor);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Gas Recycle Loop
DF(63)      = RecGasFlow.T - CompFlow.T;
DF(64)      = RecGasFlow.P - CompFlow.P;
DF(58:62)   = RecGasFlow.F - CompFlow.F;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COLUMN SYSTEM
% Input flow
Ft_stab = alg(57);		    % feed rate. See below the connection between the flash and the stabilizer column
qF      = 1;                % liquid fraction (qF = 1 is pure liquid)
x_stab  = alg(50:54);	    % stabilizer feed composition
F_stab  = Ft_stab*x_stab;	% component flow
stab_d  = [Ft_stab qF x_stab'];

X                     = diff(26:182);
U                     = [LT_stab;VB_stab;D_stab;xB_stab; LT_ben;VB_ben;D_ben;xD_ben; LT_tol;VB_tol;D_tol;xD_tol];
[L,V,D,B,xD,xB,dMxdt] = colsys(X,U,stab_d,no);

xDstab  = xD(1,:);
xBstab  = xB(1,:);
xDben   = xD(2,:);
xBben   = xB(2,:);
xDtol   = xD(3,:);
xBtol   = xB(3,:);

Lstab   = L(1);
Lben    = L(2);
Ltol    = L(3);
VBstab  = V(1);
VBben   = V(2);
VBtol   = V(3);
Dstab   = D(1);
Dben    = D(2);
Dtol    = D(3);
Bstab   = B(1);
Bben    = B(2);
Btol    = B(3);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Connection between flash and stabilizer
df      = sum(F_stab - (1 - nu)*SepLiqFlow.F); % part of SepLiqFlow (nu) goes to quencher.
DF(57)  = df;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Toluene Recycle Loop
% Input-flow
F_rectol = Dtol*xDtol; % Feed rate

df       = RecToluen.F(3) - F_rectol(3);
DF(65)   = df;
df       = RecToluen.F(4) - F_rectol(4);
DF(66)   = df;
df       = RecToluen.F(5) - F_rectol(5);
DF(67)   = df;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Time derivates
dXdt = [dCdt; dXsepdt; dMxdt];

