% ************************************************************************
% Distillation column model for steady state and dynamic calculations.
% ************************************************************************

% Splitting the states
Mi = [];
for i = 1:NT
  Mi = [Mi; X(NC*(i-1)+1:NC*i)'];          % Liquid component holdup from bottom to top
end
M = sum(Mi,2);

% THE MODEL
% Liquid composition
x = [];
for i = 1:NT
  x = [x; Mi(i,:)/sum(Mi(i,:))'];          % Liquid composition from bottom to top
end

% Vapor-liquid equilibria (multicomponent ideal VLE, Stichlmair-Fair,
% 'Distillation', p. 36, 1998)
for i = 1:NT-1
  y(i,:) = (alpha(i,1:NC-1).*x(i,1:NC-1))/(1 + sum((alpha(i,1:NC-1) - 1).*x(i,1:NC-1)));
end
y(:,NC) = 1 - sum(y,2);

%Overcool in condenser (Overcool heat, vapour condensing heat)
switch overcool
    case 34 % Stabilizer
        Q   = overcool*LT*(7*x(NT,1) + 10.1*x(NT,2) + 40.188*x(NT,3) + 53.934*x(NT,4) + 83.113*x(NT,5))/1.00e+006;
        Q1  =(13.183*y(NT-1,3) + 16.228*y(NT-1,4) + 17.131*y(NT-1,5))/1000;
        C   = Q/Q1;  %Extra liquid flow through column due to overcooling
    case 24 % Benzene column
        Q   = overcool*LT*(40.188*x(NT,1) + 53.934*x(NT,2) + 83.113*x(NT,3))/1.00e+006;
        Q1  = (13.183*y(NT-1,1) + 16.228*y(NT-1,2) + 17.131*y(NT-1,3))/1000;
        C   = Q/Q1;  %Extra liqvid flow through column due to overcooling
    case 19 % Toluene column
        Q   = overcool*LT*(40.188*x(NT,1) + 53.934*x(NT,2) + 83.113*x(NT,3))/1.00e+006;
        Q1  = (13.183*y(NT-1,1) + 16.228*y(NT-1,2) + 17.131*y(NT-1,3))/1000;
        C   = Q/Q1;  %Extra liqvid flow through column due to overcooling
end
x(NT,:) = (LT*x(NT,:) + C*y(NT-1,:))/(LT + C);

% Vapor Flows assuming constant molar flows
i = 1:NT-1;    V(i) = VB;
i = NF:NT-1;   V(i) = V(i)+(1-qF)*F;

% Liquid flows are given by Francis' Weir Formula L(i)=K*Mow(i)^1.5
% Liquid flow L(i) depends only on the holdup over the weir Mow(i)
% M(i)= Mow(i) + Muw(i) (Total holdup = holdup over weir + holdup below
% weir)
% i = 2:NT-1; L(i) = Kf(i-1).*(M(i)-Muw).^1.5; % Liquid flows above feed
% L(NT) = LT;                                  % Condenser's liquid flow

Kfb = Kf(1); Kfa = Kf(2);
i = 2:NF;       L(i) = Kfb*(M(i)-Muw).^1.5; % Liquid flows below feed
i = NF+1:NT-1;  L(i) = Kfa*(M(i)-Muw).^1.5; % Liquid flows above feed
L(NT) = LT;                                 % Condenser's liquid flow

% Time derivatives from  material balances for 
% 1) total holdup and 2) component holdup

% Column
for i = 2:NT-1 
  dMxdt(i,:) = L(i+1)*x(i+1,:) - L(i)*x(i,:) + V(i-1)*y(i-1,:) - V(i)*y(i,:);
end

% Correction for feed at the feed stage
% The feed is assumed to be mixed into the feed stage
dMxdt(NF,:) = dMxdt(NF,:) + F*zF;

% Reboiler (assumed to be an equilibrium stage)
dMxdt(1,:)  = L(2)*x(2,:) - V(1)*y(1,:) - B*x(1,:);

% Total condenser (no equilibrium stage)
dMxdt(NT,:) = V(NT-1)*y(NT-1,:) - LT*x(NT,:) - D*x(NT,:);

% Output
dMxdtT = dMxdt';
dXdt   = dMxdtT(:);


