function [c,ceq] = nonlcon(x,no)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% nonlcon - calculate residual to equality and non-equality constraints
%
% Inputs:  x    - optimization variables 
%                 (state, algebraic and manipulable variables)                 
%
% Outputs: c    - residual inequality constraints
%          ceq  - residual equality constraints
%
% Written by   : Marius S. Govatsmark        18.Aug.1998
% Last modified: Marius S. Govatsmark        28.March 2000
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

parameter

% Optimization variables (all possible candidates are included)
Fgas            = x(ndiff_alg+1);   % Gas feed flow rate
Wcooler         = x(ndiff_alg+2);   % Flow of cooling water to cooler
kpurge          = x(ndiff_alg+3);   % Purge valve opening
Wfuel           = x(ndiff_alg+4);   % Flow of fuel to furnace
Ftol            = x(ndiff_alg+5);   % Pure toluene feed flow rate
kbypass         = x(ndiff_alg+6);   % Bypass hot side in fehe
hpcompressor    = x(ndiff_alg+7);   % Compressor power
LT_stab         = x(ndiff_alg+8);   % Stabilizer reflux rate
VB_stab         = x(ndiff_alg+9);   % Stabilizer boilup rate
D_stab          = x(ndiff_alg+10);  % Stabilizer distillate rate
xB_stab         = x(ndiff_alg+11);  % Methane mole fraction in bottom
LT_ben          = x(ndiff_alg+12);  % Benzene column reflux rate
VB_ben          = x(ndiff_alg+13);  % Benzene column boilup rate
D_ben           = x(ndiff_alg+14);  % Benzene column distillate rate
xD_ben          = x(ndiff_alg+15);  % Benzene mole fraction in distillate
LT_tol          = x(ndiff_alg+16);  % Toluene column reflux rate
VB_tol          = x(ndiff_alg+17);  % Toluene column boilup rate
D_tol           = x(ndiff_alg+18);  % Toluene column distillate rate
xD_tol          = x(ndiff_alg+19);  % Toluene mole fraction in distillate
kquencher       = x(ndiff_alg+20);  % Split ratio after flash (liquid flow from flash to quencher)
kfsep           = x(ndiff_alg+21);  % Flash inlet valve opening

% Disturbances
dvar

%  Model
model

% Bounds (lower and upper) for constraints:
b = [1150       %1 - Reactor inlet temperature (lower bound)
    0.9997      %2 - Product purity (lower bound)
    1           %3 - Product purity (upper bound)
    0           %4 - By-pass valve around FEHE (lower bound)
    0.2         %5 - Methane in recycle gas stream (lower bound)
    265         %6 - Production rate - benzene (lower bound)
    Ftol_upper  %7 - Pure toluene feed rate (upper bound)
    500         %8 - Reactor inlet pressure (upper bound)
    95          %9 - Flash inlet temperature (lower bound)
    105         %10 - Flash inlet temperature (upper bound)
    5           %11 - Reactor inlet hydrogen-aromatics - ratio (lower bound)
    1300        %12 - Reactor outlet temperature (upper bound)
    0.00005     %13 - Volatile impurity (hydrogen plus methane) levels at stabilizer bottom (upper bound)
    100         %14 - Boil-up stabilizer (upper bound)
    700         %15 - Boil-up benzene column (upper bound)
    100         %16 - Boil-up toluene column (upper bound)
    100         %17 - Reflux stabilizer (upper bound)
    500         %18 - Reflux benzene column (upper bound)
    50          %19 - Reflux toluene column (upper bound)
    0.00001     %20 - Benzene mole fraction in stabilizer distillate (upper bound)
    0.87        %21 - Toluene mole fraction in benzene column bottom (lower bound)
    0.985       %22 - Toluene mole fraction in toluene column distillate (lower bound)
    0.9985      %23 - Diphenyl mole fraction in toluene column bottom (lower bound)
    1.0];       %24 - Flash inlet valve opening

constraints2

