function [F2,F3] = purge(F1,kpurge,Pdown,cvpurge)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% purge - physical data out of purge
%
% Inputs:    F1     - inlet flow purge            [struct] 
%            kpurge - valve opening               [-]
%            Pdown  - outlet pressure purge       [psia] 
%
% Outputs:   F2     - outlet flow purge - recycle [struct] 
%            F3     - outlet flow purge - out     [struct] 
%
%
% Written by    : Marius S. Govatsmark         19.sept.1998
% Last modified: Marius S. Govatsmark          22.aug.1999
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% data - dyn73.res
  DP = 0;          %[psia]

% Define struct
  F2 = stream;
  F3 = F2;

% Pressure
  F2.P = F1.P - DP;
  F3.P = Pdown;
  
% Temperature
  F2.T = F1.T;
  F3.T = F1.T;

% Flows
  F3tot = kpurge*cvpurge*((F1.P - F3.P)^0.5);
  x     = F1.F/sum(F1.F);
  F3.F  = F3tot*x;
  F2.F  = F1.F - F3.F;

% Enthalpy
  F2.E = enthalpy(F2);
  F3.E = enthalpy(F3);
  
