function [QFlow,nu] = quencher(SepLiqFlow,Fpfr,kquencher,cvquencher)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% quencher - physical data out of quencher
%
% Inputs:    SepLiqFlow  - flow out of flash            [struct]
%            Fpfr    - flow out of reactor              [struct]
%            kquencher - valve constant and opening     [-]
%
% Outputs:   QFlow - quencher outlet flow               [struct]
%            nu - ratio Sep2QuenFlow.F/SepLiqFlow.F     [-]
%
%
% Written by   : Antonio Arajo             05.aug.2005
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Data
PD = 0;
P1 = 450; % Valve upstream pressure [psia]: assumed constant since a pump is assumed to pull the liquid from the separator.

% Splitter after the flash block
Sep2QuenFlow      = stream;
Sep2QuenFlow.T    = SepLiqFlow.T;
Sep2QuenFlow.P    = Fpfr.P; % Valve downstream pressure.
Sep2QuenFlowtot   = kquencher*cvquencher*(P1 - Sep2QuenFlow.P)^0.5;
Sep2QuenFlow.F    = Sep2QuenFlowtot*(SepLiqFlow.F./sum(SepLiqFlow.F));
Sep2QuenFlow.E    = enthalpy(Sep2QuenFlow);
nu                = sum(Sep2QuenFlow.F)/sum(SepLiqFlow.F);

% Mass-stream
QFlow.F = Sep2QuenFlow.F + Fpfr.F;

% Energy-stream
QFlow.E = Sep2QuenFlow.E + Fpfr.E;

% Pressure out
QFlow.P = Fpfr.P - PD;

